
local leadWire = ...

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	leadWire:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = {
                     DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                     CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
                IsVisibleWhenBuilt = false
	})
end

-- Apply building asset processor
    leadWire:registerAssetProcessor("models/decorations/leadWire.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

-- Register common prefab nodes
    leadWire:registerAssetId("models/decorations/leadWire.fbx/Prefab/leadWire/step_0_RootPart", _PrefixAsset .. "LEAD_WIRE_ROOT_PREFAB")
    leadWire:registerAssetId("models/decorations/leadWire.fbx/Prefab/leadWire/step_3_TopPart", _PrefixAsset .. "LEAD_WIRE_TOP_PREFAB")
    leadWire:registerAssetId("models/decorations/leadWire.fbx/Prefab/leadWire/step_2_Tiling2Part", _PrefixAsset .. "LEAD_WIRE_TILING2_PREFAB")
    leadWire:registerAssetId("models/decorations/leadWire.fbx/Prefab/leadWire/step_1_Tiling1Part", _PrefixAsset .. "LEAD_WIRE_TILING1_PREFAB")

    local defaultNodePrefixList = {
	_PrefixAsset .. "LEAD_WIRE_TOP",
	_PrefixAsset .. "LEAD_WIRE_TILING2",
	_PrefixAsset .. "LEAD_WIRE_TILING1"
    }

-- Register simple building part assets
    for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
    end

-- Register the lead wire part
    leadWire:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. "LEAD_WIRE_ROOT_PART",
	Name = _PrefixAsset .. "LEAD_WIRE_ROOT_NAME",
	Description = _PrefixAsset .. "LEAD_WIRE_ROOT_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = _PrefixAsset .. "LEAD_WIRE_ROOT_PREFAB",
		EndPart = _PrefixAsset .. "LEAD_WIRE_TOP_PART",
		FillerList = {
			_PrefixAsset .. "LEAD_WIRE_TILING2_PART"
                },
		BasementFillerList = {
			_PrefixAsset .. "LEAD_WIRE_TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
        HasMaximumInstancePerBuilding = true,
        MaximumInstancePerBuilding = 1
    })

    -- Override building part components properties (generated by the building asset processor) to add building zones
    leadWire:registerPrefabComponent("models/decorations/leadWire.fbx/Prefab/leadWire/step_0_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0, 0 }
    })

    --------------------------------------------------------------------------
    -- Register LEAD_WIRE_COMP component
    leadWire:registerPrefabComponent("models/decorations/leadWire.fbx/Prefab/leadWire/step_3_TopPart", {
	DataType = _PrefixAsset .. "LEAD_WIRE_COMP",
	Enabled = true
    })

